##  Overview
The application portfolio is an essential aspect of any IT landscape. Ensuring that the portfolio is optimized to meet an organization’s operational and financial needs is the key to ongoing business success.
By reducing complexity, managing cost, and aligning applications with critical business capabilities, Enterprise Architects can help an organization to improve overall effectiveness and competitiveness. A well-organized, up-to-date application repository is essential for all these initiatives. Complex spreadsheets just can’t do the job.
Learn about the typical business drivers for application rationalization initiatives and how you can use SAP LeanIX to realize this use case. Let's go through application rationalization step by step:
  * Understand why application rationalization matters to a business and IT team, and which data points you need to kick-start this use case
  * Scope the applications for rationalization, evaluate the information in SAP LeanIX, and gain insights for decisions
  * Start the application rationalization initiative, track relevant key performance indicators (KPIs) and report to critical stakeholders
